===========
 Changelog
===========

2.4 (2017-01-21)
================

- Update code to support `icemac.addressbook >= 2.9`.


2.3 (2017-01-07)
================

- Bring branch test coverage to 100 %.

- Adapt configuration of user roles and code to `icemac.addressbook >= 2.9`.


2.2 (2016-03-05)
================

- Update to ``bootstrap.py`` from `zc.buildout 2.3.1`.

- Update tests to only run with `py.test`.

- Update code and tests to changes in `icemac.addressbook 2.6`.


Previous versions
=================

See ``OLD_CHANGES.rst`` inside the package.
